@@ -11,8 +11,7 @@ from laipvt.sysutil.conf import YamlConfig
 from laipvt.sysutil.gvalue import LAIPVT_BASE_DIR
 from laipvt.model.sql import SqlModule
 from laipvt.sysutil.command import CREATE_DB
-from laipvt.sysutil.util import get_yaml_config
-
+from laipvt.helper.errors import Helper
 
 class IdentityController(MiddlewareInterface):
     def __init__(self, result: CheckResultHandler, handler: IdentityConfigHandler, template: str):
@@ -36,7 +35,6 @@ class IdentityController(MiddlewareInterface):
         self.port = int(self.cfg["mysql"]["port"])
         self.cfg.update(self.check_result.__dict__)
     def _generic_config(self):
-        log.info("渲染 identity 配置文件")
         if self.cfg["mysql"]["is_deploy"]:
             self.cfg["mysql"]["ipaddress"] = self.handler.cfg["ipaddress"]
         if self.cfg["redis"]["is_deploy"]:
@@ -48,11 +46,10 @@ class IdentityController(MiddlewareInterface):
             self.cfg["localhost"] = self.master_server[num_id].ipaddress
             FileTemplate(self.cfg, self.identity_conf_template, self.identity_conf_tmp).fill()
             self.send_config_file(self.master_server[num_id], self.identity_conf_tmp, self.identity_conf_file)
-            self.send_config_file(self.master_server[num_id], self.identity_sql_template, self.identity_sql_file)
+            #self.send_config_file(self.master_server[num_id], self.identity_sql_template, self.identity_sql_file)
         self.generate_docker_compose_file(self.cfg)
 
     def _proxy_on_nginx(self):
-        log.info("渲染 nginx identity 代理配置文件")
         FileTemplate(self.cfg, self.identity_nginx_template, self.identity_nginx_tmp).fill()
         self.update_nginx_config()
 
@@ -60,25 +57,27 @@ class IdentityController(MiddlewareInterface):
         super().wait_for_service_start()
         for i in range(len(self.master_server)):
             try:
-                log.info("检查 {IP}:{PORT} 上的 Identity 健康性...".format(IP=self.master_server[i].ipaddress, PORT=self.cfg["identity"]["nginx_proxy_port"]))
                 requests.get(
                     "http://{IP}:{PORT}".format(
                         IP=self.master_server[i].ipaddress, PORT=self.cfg["identity"]["nginx_proxy_port"]
                     )
                 )
-                log.info("Identity检查通过")
+                log.info(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_SUCCEED.format(self.master_server[i].ipaddress,
+                                                                               self.cfg["identity"]["nginx_proxy_port"]))
             except Exception as e:
+                log.info(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_FAILED.format(self.master_server[i].ipaddress,
+                                                                              self.cfg["identity"]["nginx_proxy_port"]))
                 log.error(e)
-                log.error("{IP} 上的 Identity 服务异常".format(IP=self.master_server[i].ipaddress))
                 exit(2)
 
     def init_mysql(self):
+        log.info(Helper().INIT_IDENTITY_MYSQL_DATA)
+
         if not self.cfg["mysql"]["is_deploy"]:
             self.master_host = self.cfg["mysql"]["ipaddress"][0]
         else:
             self.cfg["mysql"]["ipaddress"] = self.handler.cfg["ipaddress"][0]
             self.master_host = self.cfg["mysql"]["ipaddress"]
-        log.info("初始化mysql identity数据表")
         db_info = walk_sql_path(path_join(self.template, "identity_sqls"))
         sql = SqlModule(host=self.master_host, port=self.port, user=self.user, passwd=self.password)
         for db_name, sql_files in db_info.items():
