@@ -9,6 +9,7 @@ from laipvt.model.sql import SqlModule
 from laipvt.model.server import ServerModel
 from laipvt.sysutil.conf import YamlConfig
 from laipvt.sysutil.gvalue import LAIPVT_BASE_DIR
+from laipvt.helper.errors import Helper
 
 
 class MysqlController(MiddlewareInterface):
@@ -43,7 +44,6 @@ class MysqlController(MiddlewareInterface):
         self.backup_sh_file = path_join(self.base_dir, "backup.sh")
 
     def gen_proxy_sql_config(self):
-        log.info("渲染分发Proxysql配置文件")
         server = ServerModel(self.master_server)
         try:
             FileTemplate(self.mysql_cfg, self.proxysql_conf_template, self.proxysql_conf_tmp).fill()
@@ -64,15 +64,12 @@ class MysqlController(MiddlewareInterface):
         self._proxy_on_nginx()
 
     def _generic_config(self):
-        log.info("渲染Mysql配置文件")
         if len(self.master_server) == 1:
-            log.info("使用单机模式部署")
             self.mysql_cfg["is_standalone"] = True
         elif len(self.master_server) == 3:
-            log.info("使用集群模式部署")
             self.mysql_cfg["is_standalone"] = False
         else:
-            log.info("集群模式需要3台主机,请检查前置检查配置是否正确")
+            log.info(Helper().CLUSTER_REQUIRES_THREE)
             exit(2)
         for num_id in range(len(self.master_server)):
             self.mysql_cfg["server_id"] = 100 + num_id
@@ -84,10 +81,10 @@ class MysqlController(MiddlewareInterface):
             self.send_config_file(self.master_server[num_id], dest, self.mysql_config_file)
             self.send_config_file(self.master_server[num_id], self.backup_conf_tmp, self.backup_conf_file)
             self.send_config_file(self.master_server[num_id], self.backup_sh_template, self.backup_sh_file)
-        self.generate_docker_compose_file(self.mysql_cfg)
+            self.generate_docker_compose_file(self.mysql_cfg)
+            self.send_docker_compose_file_hosts(host=self.master_server[num_id])
 
     def _proxy_on_nginx(self):
-        log.info("渲染Mysql代理配置文件")
         for num_id in range(len(self.master_server)):
             FileTemplate(self.mysql_cfg, self.mysql_nginx_template, self.mysql_nginx_tmp).fill()
         self.update_nginx_config()
@@ -100,17 +97,17 @@ class MysqlController(MiddlewareInterface):
         super().wait_for_service_start()
         if self.mysql_cfg["is_standalone"]:
             return True
-        log.info("构建Proxysql MysqlMgr 集群")
+        # log.info("构建Proxysql MysqlMgr 集群")
         sql = SqlModule(host=self.master_host, port=self.port, user=self.user, passwd=self.password)
         sql.import_from_file(path_join(self.template, "mgr_init/create_mgr.sql"), file_eof=";" )
         sql.import_from_file(path_join(self.template, "mgr_init/view.sql"), file_eof="$$")
 
-        log.info("Slave 节点加入mgr集群")
+        # log.info("Slave 节点加入mgr集群")
         for server in self.master_server[1:]:
             sql = SqlModule(host=server.ipaddress, port=self.port, user=self.user, passwd=self.password)
             sql.import_from_file(path_join(self.template, "mgr_init/slave_join_mgr.sql"), file_eof=";")
 
-        log.info("Proxysql 添加mgr节点")
+        # log.info("Proxysql 添加mgr节点")
         sql = SqlModule(host=self.master_host, port=6032, user="cluster", passwd="123456", connect_timeout=5)
         sql.import_from_file(path_join(self.template, "mgr_init/proxysql_join_mgr.sql"), file_eof=";")
 
@@ -120,7 +117,7 @@ class MysqlController(MiddlewareInterface):
             if not self.mysql_cfg["is_standalone"]:
                 self.port = int(self.mysql_cfg["mysql"]["proxysql_port"])
             try:
-                log.info("检查 {IP}:{PORT} 上的 MySQL 健康性".format(IP=server.ipaddress, PORT=self.port))
+                log.info(Helper().CHECK_MIDDLEWARE_SERVICE.format(self.middleware_name, server.ipaddress, self.port))
                 SqlModule(
                     host=server.ipaddress, port=self.port,
                     user=self.user, passwd=self.password,
@@ -129,23 +126,20 @@ class MysqlController(MiddlewareInterface):
                 self._read_write_test(server.ipaddress, self.port)
             except Exception as e:
                 log.error(e)
-                log.error("{IP}:{PORT} 上的 MySQL 服务异常".format(IP=server.ipaddress, PORT=self.port))
+                log.error(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_FAILED.format(server.ipaddress, self.port))
                 exit(2)
-        # if not self.handler.cfg["is_standalone"]:
-        #     self._read_write_test(self.master_host, self.handler.cfg["mysql_load"]["nginx_proxy_port"])
 
     def _read_write_test(self, Ipaddress, Port):
-        log.info("测试验证Mysql数据库读写")
         try:
             sql = SqlModule(host=Ipaddress, port=Port, user=self.user, passwd=self.password)
             sql.insert_sql("create table test.student (id int(10),name char(100),primary key (ID));")
             sql.insert_sql("insert into test.student (id,name)values(1,'Reading and writing tests');")
             sql.select("select * from test.student;")
             sql.insert_sql("drop table test.student;")
-            log.info("Mysql {IP}:{PORT} 读写测试成功...".format(IP=Ipaddress, PORT=Port))
+            log.info(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_SUCCEED.format(Ipaddress, Port))
 
         except Exception as e:
-            log.info("Mysql {IP}:{PORT} 读写测试失败...".format(IP=Ipaddress, PORT=Port))
+            log.info(Helper().CHECK_MIDDLEWARE_SERVICE_PORT_FAILED.format(Ipaddress, Port))
             log.error(e)
             exit(2)
 
@@ -163,7 +157,7 @@ class MysqlController(MiddlewareInterface):
                 sql.import_from_file(sql_file, file_eof=";\n")
 
     def run_backup_crontab(self):
-        log.info("配置Mysql 备份定时任务")
+        log.info(Helper().CONFIG_MYSQL_BACKUP_CRON)
         self.crontab_task = "01 00 * * * sudo docker run --rm  " \
                             "-v {}:/mysql-backup  -v {}:/var/lib/mysql" \
                             " -v {}:/backup.sh -v {}:/backup.conf  {}:{}/middleware/mysql_xtrabackup:5.7.32 /bin/bash "\
@@ -185,26 +179,24 @@ class MysqlController(MiddlewareInterface):
                         "echo \"{}\" >> /var/spool/cron/{}".format(self.crontab_task, server.username)]
             results = ssh_cli.run_cmdlist(cmd_list)
             if results[0]["code"] == 0 and results[1]["code"] == 0:
-                log.info("{} Crontab 定时启动并配置成功".format(server.ipaddress))
+                log.info(Helper().CONFIG_MYSQL_BACKUP_CRON_SUCCEED.format(server.ipaddress))
             else:
                 log.error(results[0]["stdout"])
                 log.error(results[1]["stdout"])
-                log.error("{} 主机 Crontab 配置失败".format(server.ipaddress))
+                log.error(Helper().CONFIG_MYSQL_BACKUP_CRON_FAILED.format(server.ipaddress))
                 exit(2)
 
     def create_mysql_service_kubernetes(self):
-        log.info("渲染初始化Mysql Service in Kubernetes")
         server = ServerModel(self.master_server)
         FileTemplate(self.mysql_cfg, self.mysql_service_file_template, self.mysql_service_file_dest).fill()
         server.send_file(self.mysql_service_file_dest, self.mysql_service_file_remote)
 
-        log.info("在kubernetes集群内创建Mysql Service")
         cmd = "kubectl apply -f {}".format(self.mysql_service_file_remote)
         ssh_cli = ssh_obj(ip=self.master_server[0].ipaddress, user=self.master_server[0].username,
                           password=self.master_server[0].password, port=self.master_server[0].port)
         results = ssh_cli.run_cmd(cmd)
         if results["code"] != 0:
-            log.error("kubernetes集群内创建Mysql Service失败:{} {}".format(results["stdout"], results["stderr"]))
+            log.error("{} {}".format(results["stdout"], results["stderr"]))
             exit(2)
 
     @status_me("middleware")
@@ -212,7 +204,6 @@ class MysqlController(MiddlewareInterface):
         if self.check_is_deploy(self.mysql_cfg):
             self._generic_config()
             self._fill_init_sql()
-            self.send_docker_compose_file()
             self.start()
             self.run_backup_crontab()
             self._create_mgr_cluster()
