@@ -7,6 +7,7 @@ from laipvt.handler.middlewarehandler import RedisConfigHandler
 from laipvt.handler.confighandler import CheckResultHandler
 from laipvt.sysutil.template import FileTemplate
 from laipvt.sysutil.util import path_join, log, status_me
+from laipvt.helper.errors import Helper
 
 
 class RedisController(MiddlewareInterface):
@@ -22,13 +23,13 @@ class RedisController(MiddlewareInterface):
         self.redis_cfg["redis"]["ipaddress"] =  self.handler.cfg["ipaddress"]
 
     def _generic_config(self):
-        log.info("渲染 Redis 配置文件")
         for num_id in range(len(self.master_server)):
             if num_id == 0:
                 self.redis_cfg["redis"]["master_ip"] = self.master_server[num_id].ipaddress
                 self.redis_cfg["redis"]["isslave"] = False
             else:
                 self.redis_cfg["redis"]["isslave"] = True
+            self.redis_cfg["sentinel_master_ip"] = self.master_server[num_id].ipaddress
             FileTemplate(self.redis_cfg, self.redis_conf_template, self.redis_conf_tmp).fill()
             FileTemplate(self.redis_cfg, self.redis_stand_template, self.redis_stand_tmp).fill()
             self.send_config_file(self.master_server[num_id], self.redis_conf_tmp, self.redis_conf_file)
@@ -50,23 +51,21 @@ class RedisController(MiddlewareInterface):
                 password=self.redis_cfg["redis"]["password"],
                 db=15
                 )
-            if master:
-                log.info("Redis master 服务正常")
-            if self.handler.cfg["deploy_type"] == "single":
+            if self.handler.cfg["deploy_type"] == "single" and master:
+                log.info(Helper().CHECK_REDIS_SERVICE_SUCCEED)
                 return True
             r = master.set(key, value)
             if r:
-                log.info("Redis master 写入正常")
                 slave = cli.slave_for(
                     self.redis_cfg["redis"]["master_name"],
                     password=self.redis_cfg["redis"]["password"],
                     db=15
                 )
                 if slave.get(key).decode() == value:
-                    log.info("Redis slave 读取正常")
+                    log.info(Helper().CHECK_REDIS_SERVICE_SUCCEED)
                     return True
         except Exception as e:
-            log.error("Redis 集群配置失败,请检查：{}".format(e))
+            log.error(Helper().CHECK_REDIS_SERVICE_FAILED.format(e))
 
     @status_me("middleware")
     def deploy_redis(self):
