@@ -8,14 +8,7 @@ from laipvt.sysutil.util import path_join, status_me
 class CaptchaController(ServiceInterface):
     def __init__(self, check_result, service_path):
         super(CaptchaController, self).__init__(check_result, service_path)
-        self.project = "mage"
-
-        self.captcha_model_src = path_join(self.data_dir, "verification-tf-serving/model")
-        self.captcha_model_remote = path_join(self.deploy_dir, "verification-tf-serving/model")
-
-    @status_me("captcha")
-    def prepare_captcha(self):
-        self._send_file(src=self.captcha_model_src, dest=self.captcha_model_remote)
+        self.tf_name = "verification"
 
     @status_me("captcha")
     def push_captcha_images(self):
@@ -23,9 +16,15 @@ class CaptchaController(ServiceInterface):
 
     @status_me("captcha")
     def start_captcha_service(self):
-        self.start_service(project=self.project, version=self.private_deploy_version)
+        self._create_namespace(namespaces=self.namespaces,
+                               istio_injection_namespaces=self.istio_injection_namespaces)
+        self.start_service(project=self.project, version=self.private_deploy_version, tf_name=self.tf_name)
+
+    @status_me("captcha")
+    def prepare_captcha_data(self):
+        self.prepare_data(project=self.project)
 
     def run(self):
-        self.prepare_captcha()
         self.push_captcha_images()
         self.start_captcha_service()
+        self.prepare_captcha_data()
