@@ -8,14 +8,20 @@ from kubernetes.config.kube_config import KUBE_CONFIG_DEFAULT_LOCATION
 from laipvt.helper.exception import ModelError
 from laipvt.sysutil.util import log, path_join
 from laipvt.handler.middlewarehandler import HarborConfigHandler
+from laipvt.helper.errors import Helper
 
 
-class DockerModel():
+class DockerModel:
     def __init__(self, url=None):
         self.client = docker.APIClient(base_url=url, timeout=300)
 
     def _image_generator_parse(self, gen: any) -> str:
-        image_name = next(gen)["stream"].split(" ")[-1].replace("\n", "")
+        image_name = []
+        # log.info(image_name)
+        for imageName in gen:
+            image_name.append(imageName["stream"].split(" ")[-1].replace("\n", ""))
+        # image_name = next(gen)["stream"].split(" ")[-1].replace("\n", "")
+        # exit()
         return image_name
 
     def _parse_tag(self, image: str) -> dict:
@@ -58,7 +64,7 @@ class DockerModel():
 
 
 class DockerImageModel(DockerModel):
-    def __init__(self, image: str, project: str, repo: str):
+    def __init__(self, image: str, project: str, repo: str, tag_version: str):
         """
         :param image: /tmp/etcd.tar
         :param project: middleware
@@ -71,6 +77,7 @@ class DockerImageModel(DockerModel):
         self.image = image # 要导入的镜像文件路径
         self.repo_path = "{}/{}".format(repo, project)
         self.new_image_addr = None
+        self.tag_version = tag_version
         try:
             harbor_cfg = HarborConfigHandler().get_config_with_check_result()
             self.auth_config = {
@@ -81,20 +88,36 @@ class DockerImageModel(DockerModel):
             log.error(e)
             self.auth_config = None
 
+    def _parse_tag(self, image: str) -> dict:
+        """
+        :param image: tfserver:2.2.0-gpu
+        :return: {"image_name": tfserver, "image_tag": 2.2.0-gpu}
+        """
+        try:
+            t = image.split(":")
+            return {"image_name": t[0], "image_tag": self.tag_version}
+        except AttributeError as e:
+            log.error(Helper().PUSH_IMAGE_ERROR.format(image, e))
+            exit(2)
+        return {"image_name": "", "image_tag": self.tag_version}
+
+
     def run(self) -> bool:
         image_name_withtag = self.load(self.image)
-        image_name = self._parse_tag(image_name_withtag)
-        new_image_name = image_name["image_name"].split("/")[-1]
-        log.debug("更新镜像tag 镜像: {}, 新地址: {}, tag: {}".format(
-            image_name_withtag,
-            path_join(self.repo_path, new_image_name),
-            image_name["image_tag"]
-        ))
-        if self.tag(image_name_withtag, path_join(self.repo_path, new_image_name), image_name["image_tag"]):
-            self.new_image_addr = path_join(self.repo_path, new_image_name)
-            return self.push(path_join(self.repo_path, new_image_name), image_name["image_tag"], auth_config=self.auth_config)
+        for image in image_name_withtag:
+            image_name = self._parse_tag(image)
+            new_image_name = image_name["image_name"].split("/")[-1]
+            log.info(Helper().TAG_IMAGE.format(
+                image,
+                path_join(self.repo_path, new_image_name),
+                image_name["image_tag"]
+            ))
+            if self.tag(image, path_join(self.repo_path, new_image_name), image_name["image_tag"]):
+                self.new_image_addr = path_join(self.repo_path, new_image_name)
+                self.push(path_join(self.repo_path, new_image_name), image_name["image_tag"], auth_config=self.auth_config)
         return False
 
+
 class ComposeModel(object):
     """
     :return string
@@ -129,7 +152,8 @@ class ComposeModel(object):
     def restart(self) -> str:
         return "%s -f %s restart" % (self.compose, self.compose_file)
 
-class KubeModel():
+
+class KubeModel:
     def __init__(self, config_file=KUBE_CONFIG_DEFAULT_LOCATION):
         config.load_kube_config(config_file=config_file)
         self.cli = client.CoreV1Api()
@@ -159,15 +183,14 @@ class KubeModel():
         all_nodes = self.cli.list_node(pretty='true')
         node_info = []
         for node in all_nodes.items:
-            info = {}
-            info['name'] = node.metadata.name
+            info = {'name': node.metadata.name}
             for st in node.status.conditions:
                 if st.reason == "KubeletReady":
                     info["status"] = st.type
             node_info.append(info)
         return node_info
 
-    def get_all_pod_status(self) -> list:
+    def get_all_pod_status(self, namespace="all_namespaces") -> list:
         """
         获取所有命令空间下的pod状态
         : return list
@@ -183,11 +206,13 @@ class KubeModel():
             "namespace":"mid",
             "pod_name":"license-manager-7d56c5f687-nsmzx",
             "status":"Running"
-        }
-    ]
+        }]
         """
-        v1 = client.CoreV1Api()
-        ret = v1.list_pod_for_all_namespaces(watch=False, pretty='true')
+        if namespace == "all_namespaces":
+            ret = self.cli.list_pod_for_all_namespaces(watch=False, pretty='true')
+        else:
+            ret = self.cli.list_namespaced_pod(namespace=namespace)
+
         pod_info = []
         for item in ret.items:
             pod_info.append(
